package svc

import (
	"applet/app/admin/md"
	svc "applet/app/admin/svc/enterprise_manage"
	md2 "applet/app/customer/md"
	svc2 "applet/app/customer/svc"
	"applet/app/db"
	"applet/app/enum"
	"applet/app/utils"
	"errors"
)

func CentralKitchenForSchoolOrderRefundList(req md.CentralKitchenForSchoolOrderRefundListReq) (resp []md.CentralKitchenForSchoolOrderRefundListResp, total int64, err error) {
	var m []*db.CentralKitchenForSchoolUserRefundDayWithData
	sess := db.Db.Where("1=1")
	if req.EnterpriseId != 0 {
		sess.And("enterprise.id =?", req.EnterpriseId)
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Name+"%")
	}
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Phone+"%")
	}
	if req.Kind != 0 {
		sess.And("central_kitchen_for_school_user_with_day.kind = ?", req.Kind)
	}
	if req.State != 0 {
		sess.And("central_kitchen_for_school_user_refund_day.state = ?", req.State)
	}
	if req.StartDate != "" {
		sess.And("central_kitchen_for_school_user_refund_day.create_at >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("central_kitchen_for_school_user_refund_day.create_at <= ?", req.EndDate)
	}
	if req.OutTradeNo != "" {
		sess.And("central_kitchen_for_school_user_refund_day.out_trade_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.OutRequestNo != "" {
		sess.And("central_kitchen_for_school_user_refund_day.out_request_no like ?", "%"+req.OutRequestNo+"%")
	}

	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, 0, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, 0, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	total, err = sess.
		Join("LEFT", "central_kitchen_for_school_user_with_day", "central_kitchen_for_school_user_refund_day.records_id = central_kitchen_for_school_user_with_day.id").
		Join("LEFT", "central_kitchen_for_school_package_ord", "central_kitchen_for_school_user_refund_day.out_trade_no = central_kitchen_for_school_package_ord.out_trade_no").
		Join("LEFT", "user_identity", "central_kitchen_for_school_user_with_day.identity_id = user_identity.id").
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "enterprise", "user_identity.enterprise_id = enterprise.id").
		Join("LEFT", "class_with_user", "user_identity.id = class_with_user.user_identity_id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.CentralKitchenForSchoolOrderRefundListResp{
			Id:             v.CentralKitchenForSchoolUserRefundDay.Id,
			OutTradeNo:     v.CentralKitchenForSchoolUserRefundDay.OutTradeNo,
			OutRequestNo:   v.CentralKitchenForSchoolUserRefundDay.OutRequestNo,
			Name:           v.UserIdentity.Name,
			Phone:          v.User.Phone,
			EnterpriseName: v.Enterprise.Name,
			ClassName:      v.Class.Name,
			GradeName:      v.Grade.Name,
			Kind:           v.CentralKitchenForSchoolUserWithDay.Kind,
			Amount:         v.CentralKitchenForSchoolUserRefundDay.Amount,
			State:          v.CentralKitchenForSchoolUserRefundDay.State,
			CreateAt:       v.CentralKitchenForSchoolUserRefundDay.CreateAt,
			Memo:           v.CentralKitchenForSchoolUserRefundDay.Memo,
		})
	}
	return
}

func CentralKitchenForSchoolOrderRefundAudit(req md.CentralKitchenForSchoolOrderRefundAuditReq) (err error) {
	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum.JsapiPayAppAutToken, enum.OpenAlipayAppid, enum.OpenAlipayAppPrivateKey, enum.OpenAlipayPublicKey)

	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//限制30条
	if len(req.Ids) > 30 {
		err = errors.New("受理数据过长，请分批次处理")
		_ = session.Rollback()
		return
	}
	centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
	centralKitchenForSchoolUserRefundDayDb.Set(0)
	centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
	centralKitchenForSchoolUserWithDayDb.Set(0)
	for _, v := range req.Ids {
		returnDay, err1 := centralKitchenForSchoolUserRefundDayDb.GetCentralKitchenForSchoolUserRefundDay(utils.StrToInt(v))
		if err1 != nil {
			_ = session.Rollback()
			return err1
		}
		if returnDay.State != enum.CentralKitchenForSchoolUserRefundDayStateForAuditing {
			_ = session.Rollback()
			return errors.New("请勿重复审核申请单！")
		}
		userWithDay, err3 := centralKitchenForSchoolUserWithDayDb.GetCentralKitchenForSchoolUserWithDay(returnDay.RecordsId)
		if err3 != nil {
			_ = session.Rollback()
			return err3
		}

		//1、更新状态
		if req.State == 1 {
			returnDay.State = enum.CentralKitchenForSchoolUserRefundDayStateForAuditPass
			userWithDay.State = enum.CentralKitchenForSchoolUserWithDayStateForCancel
		} else {
			returnDay.State = enum.CentralKitchenForSchoolUserRefundDayStateForAuditReject
			userWithDay.State = enum.CentralKitchenForSchoolUserWithDayStateForWait
		}
		returnDay.Memo = req.Memo
		updateAck, err2 := centralKitchenForSchoolUserRefundDayDb.CentralKitchenForSchoolUserRefundDayUpdate(returnDay.Id, returnDay, "state", "memo")
		if err2 != nil {
			_ = session.Rollback()
			return err2
		}
		if updateAck <= 0 {
			_ = session.Rollback()
			err = errors.New("更新退款订单记录状态失败")
			return
		}
		updateAck1, err4 := centralKitchenForSchoolUserWithDayDb.CentralKitchenForSchoolUserWithDayUpdate(userWithDay.Id, userWithDay, "state")
		if err4 != nil {
			_ = session.Rollback()
			return err4
		}
		if updateAck1 <= 0 {
			_ = session.Rollback()
			err = errors.New("更新退款就餐记录状态失败")
			return
		}

		//2、处理订单状态
		err5 := svc.JudgePackageOrdOrdState(returnDay.OutTradeNo)
		if err5 != nil {
			_ = session.Rollback()
			return err5
		}

		//3、调用支付宝进行退款
		if req.State == 1 {
			err6, _ := svc2.CurlAlipayTradeRefund(md2.CurlAlipayTradeRefundReq{
				Config: struct {
					PayAliAppId      string `json:"pay_ali_app_id" label:"支付宝开放平台-第三方应用-appid"`
					PayAliPrivateKey string `json:"pay_ali_private_key" label:"支付宝开放平台-第三方应用-接口加签-应用私钥"`
					PayAliPublicKey  string `json:"pay_ali_public_key" label:"支付宝开放平台-第三方应用-接口加签-支付宝公钥"`
				}{
					PayAliAppId:      sysCfg[enum.OpenAlipayAppid],
					PayAliPrivateKey: sysCfg[enum.OpenAlipayAppPrivateKey],
					PayAliPublicKey:  sysCfg[enum.OpenAlipayPublicKey],
				},
				OutTradeNo:   returnDay.OutTradeNo,
				RefundAmount: returnDay.Amount,
				RefundReason: "央厨订餐退款",
				OutRequestNo: returnDay.OutRequestNo,
				AppAuthToken: sysCfg[enum.JsapiPayAppAutToken],
			})
			if err6 != nil {
				_ = session.Rollback()
				return err6
			}
		}
	}

	return session.Commit()
}
