package hdl

import (
	"applet/app/admin/lib/validate"
	"applet/app/customer/md"
	svc "applet/app/customer/svc/order"
	"applet/app/db"
	"applet/app/e"
	"applet/app/enum"
	"applet/app/utils"
	"github.com/gin-gonic/gin"
	"time"
)

func CentralKitchenForSchoolOrderList(c *gin.Context) {
	var req md.CentralKitchenForSchoolOrderListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	list, total, err := svc.OrderList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"ord_state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForWait),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete,
			},
		},
		"kind_list": []map[string]string{
			{
				"name":  "按学期购买",
				"value": "1",
			},
			{
				"name":  "按月购买",
				"value": "2",
			},
			{
				"name":  "按天购买",
				"value": "3",
			},
			{
				"name":  "补餐",
				"value": "4",
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolOrderDetail(c *gin.Context) {
	outTradeNo := c.DefaultQuery("out_trade_no", "")
	centralKitchenForSchoolPackageOrd := db.CentralKitchenForSchoolPackageOrd{}
	centralKitchenForSchoolPackageOrd.Set(outTradeNo)
	ord, err := centralKitchenForSchoolPackageOrd.GetCentralKitchenForSchoolPackageOrd()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if ord == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应订单记录")
		return
	}
	centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
	centralKitchenForSchoolUserWithDayDb.Set(0)
	list, err := centralKitchenForSchoolUserWithDayDb.FindCentralKitchenForSchoolUserWithDayByOrdNo(ord.OutTradeNo)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	var total, totalBreakfast, totalLunch, totalDinner int
	total = len(*list)
	for _, v := range *list {
		if v.Kind == enum.CentralKitchenForSchoolUserWithDayKindForBreakfast {
			totalBreakfast++
		}
		if v.Kind == enum.CentralKitchenForSchoolUserWithDayKindForLunch {
			totalLunch++
		}
		if v.Kind == enum.CentralKitchenForSchoolUserWithDayKindForDinner {
			totalDinner++
		}
	}

	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(ord.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"enterprise":      enterprise,
		"total":           total,
		"ord_info":        ord,
		"total_breakfast": totalBreakfast,
		"total_lunch":     totalLunch,
		"total_dinner":    totalDinner,
		"ord_state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForWait),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete,
			},
		},
		"kind_list": []map[string]string{
			{
				"name":  "按学期购买",
				"value": "1",
			},
			{
				"name":  "按月购买",
				"value": "2",
			},
			{
				"name":  "按天购买",
				"value": "3",
			},
			{
				"name":  "补餐",
				"value": "4",
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolOrderBelowWithDay(c *gin.Context) {
	outTradeNo := c.DefaultQuery("out_trade_no", "")
	centralKitchenForSchoolPackageOrd := db.CentralKitchenForSchoolPackageOrd{}
	centralKitchenForSchoolPackageOrd.Set(outTradeNo)
	ord, err := centralKitchenForSchoolPackageOrd.GetCentralKitchenForSchoolPackageOrd()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if ord == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应订单记录")
		return
	}
	centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
	centralKitchenForSchoolUserWithDayDb.Set(0)
	list, err := centralKitchenForSchoolUserWithDayDb.FindCentralKitchenForSchoolUserWithDayByOrdNoAndState(ord.OutTradeNo, enum.CentralKitchenForSchoolUserWithDayStateForWait)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list":               list,
		"allow_refund_state": enum.CentralKitchenForSchoolUserWithDayStateForWait,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolOrderRefund(c *gin.Context) {
	var req md.CentralKitchenForSchoolOrderRefundReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc.CentralKitchenForSchoolOrderRefund(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolOrderRefundList(c *gin.Context) {
	var req md.CentralKitchenForSchoolOrderRefundListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	list, total, err := svc.CentralKitchenForSchoolOrderRefundList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserRefundDayState.String(enum.CentralKitchenForSchoolUserRefundDayStateForAuditing),
				"value": enum.CentralKitchenForSchoolUserRefundDayStateForAuditing,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserRefundDayState.String(enum.CentralKitchenForSchoolUserRefundDayStateForAuditPass),
				"value": enum.CentralKitchenForSchoolUserRefundDayStateForAuditPass,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserRefundDayState.String(enum.CentralKitchenForSchoolUserRefundDayStateForAuditReject),
				"value": enum.CentralKitchenForSchoolUserRefundDayStateForAuditReject,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserRefundDayState.String(enum.CentralKitchenForSchoolUserRefundDayStateForAuditComplete),
				"value": enum.CentralKitchenForSchoolUserRefundDayStateForAuditComplete,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolMyReserve(c *gin.Context) {
	date := c.DefaultQuery("date", "")
	userIdentityId := c.DefaultQuery("user_identity_id", "")
	if date == "" {
		e.OutErr(c, e.ERR_INVALID_ARGS, "日期不能为空")
		return
	}
	startDate := date + "-01"
	startDateTime, _ := time.Parse("2006-01-02", startDate)
	endDate := startDateTime.AddDate(0, 1, -1).Format("2006-01-02")
	err, resp := svc.CentralKitchenForSchoolMyReserve(utils.StrToInt(userIdentityId), date, startDate, endDate)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"info": resp,
	}, nil)
	return
}
