package hdl

import (
	"applet/app/customer/lib/validate"
	"applet/app/customer/md"
	"applet/app/customer/svc"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	svc2 "applet/app/svc"
	"applet/app/utils"
	"fmt"
	"github.com/gin-gonic/gin"
	"time"
)

func Login(c *gin.Context) {
	var req md.LoginReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userDb := db.UserDb{}
	userDb.Set()
	user, err := userDb.GetUserByPhone(req.Phone)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err)
		return
	}
	if user == nil {
		e.OutErr(c, e.ERR_NO_DATA, "用户信息不存在")
		return
	}
	ip := utils.GetIP(c.Request)
	key := fmt.Sprintf(md.UserJwtTokenKey, ip, utils.AnyToString(user.Id))
	token, err := svc.HandleLoginToken(key, user)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, md.LoginResponse{
		Token: token,
	}, nil)
	return
}

func Register(c *gin.Context) {
	var req md.RegisterReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = svc2.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	now := time.Now()
	userDb := db.UserDb{}
	userDb.Set()
	user, err := userDb.GetUserByPhone(req.Phone)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err)
		return
	}
	if user == nil {
		user = &model.User{
			UserId:   req.UserId,
			Nickname: req.Nickname,
			Avatar:   req.Avatar,
			Phone:    req.Phone,
			Memo:     "",
			CreateAt: now.Format("2006-01-02 15:04:05"),
			UpdateAt: now.Format("2006-01-02 15:04:05"),
		}
		insertAffected, err1 := userDb.UserInsert(user)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1)
			return
		}
		if insertAffected <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "新增用户数据失败")
			return
		}
	} else {
		user.UserId = req.UserId
		if req.Nickname != "" {
			user.Nickname = req.Nickname
		}
		if req.Avatar != "" {
			user.Avatar = req.Avatar
		}
		user.UpdateAt = now.Format("2006-01-02 15:04:05")
		updateAffected, err1 := userDb.UpdateUser(user, "user_id", "nickname", "avatar", "update_at")
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1)
			return
		}
		if updateAffected <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "更新用户数据失败")
			return
		}
	}

	ip := utils.GetIP(c.Request)
	key := fmt.Sprintf(md.UserJwtTokenKey, ip, utils.AnyToString(user.Id))
	token, err := svc.HandleLoginToken(key, user)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, md.LoginResponse{
		Token: token,
	}, nil)
	return
}
